changeset 3679:3cd35185af63 octave-forge

* small modifies in: __getx.m, __init.m, __mse.m __newnetwork.m and all files beginning with __print*
author michaelschmid
date Mon, 23 Jul 2007 15:03:54 +0000
parents e7fa6e3a8577
children 4dcd5e38603c
files main/nnet/inst/__getx.m main/nnet/inst/__init.m main/nnet/inst/__mse.m main/nnet/inst/__newnetwork.m main/nnet/inst/__printAdaptFcn.m main/nnet/inst/__printAdaptParam.m main/nnet/inst/__printB.m main/nnet/inst/__printBiasConnect.m main/nnet/inst/__printBiases.m main/nnet/inst/__printIW.m main/nnet/inst/__printInitFcn.m main/nnet/inst/__printInitParam.m main/nnet/inst/__printInputConnect.m main/nnet/inst/__printInputWeights.m main/nnet/inst/__printInputs.m main/nnet/inst/__printLW.m main/nnet/inst/__printLayerConnect.m main/nnet/inst/__printLayers.m main/nnet/inst/__printMLPHeader.m main/nnet/inst/__printNumInputDelays.m main/nnet/inst/__printNumInputs.m main/nnet/inst/__printNumLayerDelays.m main/nnet/inst/__printNumLayers.m main/nnet/inst/__printNumOutputs.m main/nnet/inst/__printNumTargets.m main/nnet/inst/__printOutputConnect.m main/nnet/inst/__printOutputs.m main/nnet/inst/__printPerformFcn.m main/nnet/inst/__printPerformParam.m main/nnet/inst/__printTargetConnect.m main/nnet/inst/__printTargets.m main/nnet/inst/__printTrainFcn.m main/nnet/inst/__printTrainParam.m
diffstat 33 files changed, 139 insertions(+), 174 deletions(-) [+]
line wrap: on
line diff
--- a/main/nnet/inst/__getx.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__getx.m	Mon Jul 23 15:03:54 2007 +0000
@@ -24,9 +24,8 @@
 ## @noindent
 ## @end deftypefn
 
-## @seealso{setx}
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function x = __getx(net)
 
--- a/main/nnet/inst/__init.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__init.m	Mon Jul 23 15:03:54 2007 +0000
@@ -31,9 +31,8 @@
 ## @noindent
 ## @end deftypefn
 
-## @seealso{}
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function net=__init(net)
 
--- a/main/nnet/inst/__mse.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__mse.m	Mon Jul 23 15:03:54 2007 +0000
@@ -29,7 +29,7 @@
 
 ## @seealso{}
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function perf = __mse(E)
 
--- a/main/nnet/inst/__printAdaptFcn.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printAdaptFcn.m	Mon Jul 23 15:03:54 2007 +0000
@@ -23,7 +23,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printAdaptFcn(fid,net)
 
--- a/main/nnet/inst/__printAdaptParam.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printAdaptParam.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
 ## Copyright (C) 2006 Michel D. Schmid <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printAdaptParam(fid,net)
 
--- a/main/nnet/inst/__printB.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printB.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
 ## Copyright (C) 2006 Michel D. Schmid <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printB(fid,net)
 
--- a/main/nnet/inst/__printBiasConnect.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printBiasConnect.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
 ## Copyright (C) 2006 Michel D. Schmid <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 
 function __printBiasConnect(fid,net)
--- a/main/nnet/inst/__printBiases.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printBiases.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
 ## Copyright (C) 2006 Michel D. Schmid <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printBiases(fid,net)
 
--- a/main/nnet/inst/__printIW.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printIW.m	Mon Jul 23 15:03:54 2007 +0000
@@ -22,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printIW(fid,net)
 
--- a/main/nnet/inst/__printInitFcn.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printInitFcn.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
 ## Copyright (C) 2006 Michel D. Schmid <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 
 function __printInitFcn(fid,net)
--- a/main/nnet/inst/__printInitParam.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printInitParam.m	Mon Jul 23 15:03:54 2007 +0000
@@ -22,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printInitParam(fid,net)
 
--- a/main/nnet/inst/__printInputConnect.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printInputConnect.m	Mon Jul 23 15:03:54 2007 +0000
@@ -22,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printInputConnect(fid,net)
 
--- a/main/nnet/inst/__printInputWeights.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printInputWeights.m	Mon Jul 23 15:03:54 2007 +0000
@@ -22,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printInputWeights(fid,net)
 
--- a/main/nnet/inst/__printInputs.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printInputs.m	Mon Jul 23 15:03:54 2007 +0000
@@ -22,7 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
 function __printInputs(fid,net)
 
--- a/main/nnet/inst/__printLW.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printLW.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printLW(fid,net)
 
--- a/main/nnet/inst/__printLayerConnect.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printLayerConnect.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## e-mail: michaelschmid@users.sourceforge.net
+## Author: Michel D. Schmid
 
 function __printLayerConnect(fid,net)
 
--- a/main/nnet/inst/__printLayers.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printLayers.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printLayers(fid,net)
 
--- a/main/nnet/inst/__printMLPHeader.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printMLPHeader.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid   <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printMLPHeader(fid)
 
--- a/main/nnet/inst/__printNumInputDelays.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printNumInputDelays.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,8 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
+
 
 function __printNumInputDelays(fid,net)
 
--- a/main/nnet/inst/__printNumInputs.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printNumInputs.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,8 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
+
 
 function __printNumInputs(fid,net)
 
--- a/main/nnet/inst/__printNumLayerDelays.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printNumLayerDelays.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printNumLayerDelays(fid,net)
 
--- a/main/nnet/inst/__printNumLayers.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printNumLayers.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printNumLayers(fid,net)
 
--- a/main/nnet/inst/__printNumOutputs.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printNumOutputs.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printNumOutputs(fid,net)
 
--- a/main/nnet/inst/__printNumTargets.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printNumTargets.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printNumTargets(fid,net)
 
--- a/main/nnet/inst/__printOutputConnect.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printOutputConnect.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## e-mail: michaelschmid@users.sourceforge.net
+## Author: Michel D. Schmid
 
 function __printOutputConnect(fid,net)
 
--- a/main/nnet/inst/__printOutputs.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printOutputs.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,8 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
+
 
 function __printOutputs(fid,net)
 
--- a/main/nnet/inst/__printPerformFcn.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printPerformFcn.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printPerformFcn(fid,net)
 
--- a/main/nnet/inst/__printPerformParam.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printPerformParam.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid 
 
 function __printPerformParam(fid,net)
 
--- a/main/nnet/inst/__printTargetConnect.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printTargetConnect.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## e-mail: michaelschmid@users.sourceforge.net
+## Author: Michel D. Schmid
 
 function __printTargetConnect(fid,net)
 
--- a/main/nnet/inst/__printTargets.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printTargets.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid 
 
 function __printTargets(fid,net)
 
--- a/main/nnet/inst/__printTrainFcn.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printTrainFcn.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,8 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
+
 
 function __printTrainFcn(fid,net)
 
--- a/main/nnet/inst/__printTrainParam.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__printTrainParam.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,19 +1,18 @@
-## Copyright (C) 2006 Michel D. Schmid
+## Copyright (C) 2006 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
-## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but
+## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
+## along with this program; see the file COPYING.  If not, write to the Free
 ## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ## 02110-1301, USA.
 
@@ -23,8 +22,7 @@
 ## to a *.txt file with identification @code{fid}.
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
-## $Revision$, $Date$
+## Author: Michel D. Schmid
 
 function __printTrainParam(fid,net)
--- a/main/nnet/inst/__newnetwork.m	Fri Jul 20 16:14:23 2007 +0000
+++ b/main/nnet/inst/__newnetwork.m	Mon Jul 23 15:03:54 2007 +0000
@@ -1,4 +1,4 @@
-## Copyright (C) 2005 Michel D. Schmid    <michaelschmid@users.sourceforge.net>
+## Copyright (C) 2005 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
 ##
 ## This program is free software; you can redistribute it and/or modify it
@@ -17,32 +17,34 @@
 ## 02110-1301, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {}{@var{net}} = __newnetwork(@var{numInputs},@var{numLayers},@var{numOutputs})
+## @deftypefn {Function File} {}{@var{net}} = __newnetwork(@var{numInputs},@var{numLayers},@var{numOutputs},@var{networkType})
 ## @code{__newnetwork} create a custom 'zero'-network
 ##
 ##
 ## @example
-## net = __newnetwork(numInputs,numLayers,numOutputs)
+## net = __newnetwork(numInputs,numLayers,numOutputs,networkType)
 ##
 ## numInputs : number of input vectors, actually only 1 allowed
 ## numLayers : number of layers
 ## numOutputs: number of output vectors, actually only 1 allowed
+## networkType: e.g. feed-forward-network "newff"
 ## @end example
 ##
 ## @example
 ## net = __newnetwork(1,2,1)
 ##       1 input layer, two hidden layers and one output layer
 ## @end example
 ##
 ## @noindent
 ## @end deftypefn
 
-## Author: Michel D. Schmid <michaelschmid@users.sourceforge.net>
+## Author: Michel D. Schmid
 
-function net = __newnetwork(numInputs,numLayers,numOutputs)
+function net = __newnetwork(numInputs,numLayers,numOutputs,networkType)
 
   ## check range of input arguments
-  error(nargchk(3,3,nargin))
+  error(nargchk(4,4,nargin))
 
   ## check input args
   if ( !isposint(numInputs) )
@@ -58,11 +60,16 @@
     error("network: not enough layers are defined! ")
   endif
 
+  ## define network type
+  net.networkType = networkType;
+
   ## ZERO NETWORK
   net.numInputs = 0;
   net.numLayers = 0;
   net.numInputDelays = 0;
   net.numLayerDelays = 0;
+  # the next five parameters aren't used till now, they are used
+  # only for matlab nnet type compatibility ==> saveMLPStruct
   net.biasConnect = [];   # not used parameter till now
   net.inputConnect = [];  # not used parameter till now
   net.layerConnect = [];  # not used parameter till now
@@ -146,10 +153,7 @@
 
     for iRuns=1:numLayers
       net.layers{iRuns,1}.dimension = 0;
-      net.layers{iRuns,1}.distanceFcn = "";
-      net.layers{iRuns,1}.distances = [];
       net.layers{iRuns,1}.netInputFcn = "";
-      net.layers{iRuns,1}.positions = [];
       net.layers{iRuns,1}.size = 0;
       net.layers{iRuns,1}.transferFcn = "tansig";
       net.layers{iRuns,1}.userdata = "Put your custom informations here!";
@@ -188,4 +192,4 @@
 #
 # ================================================================
 
-endfunction
+endfunction
\ No newline at end of file
@@ -17,32 +17,34 @@
 ##
 ## @example
-## net = __newnetwork(1,2,1)
-##       1 input layer, two hidden layers and one output layer
+## net = __newnetwork(1,2,1,"newff")
+##       1 input layer, two hidden layers, one output layer
+##       and the network type
 ## @end example
 ##